import numpy as np

def load_mol_setup(file_path):
	import os
	if not os.path.isfile(file_path):
		if os.path.isfile(file_path + ".npz"):
			file_path += ".npz"
		else:
			assert False, "File '%s' not found!" % file_path
	setup = np.load(file_path)
	return setup['types'], setup['charges']

def extract_mol_setup_from_pdb(pdb_path, save_file_path=None):
    from simtk.openmm import app, openmm
    # mapping: H: 1, C: 2, O: 3, N: 4, S: 5 for amino acids
    mapping = {'H':1, 'C':2, 'O':3, 'N':4, 'S':5}
    pdb = app.PDBFile(pdb_path)
    t = pdb.getTopology()
    ff = app.ForceField("amber99sbildn.xml")
    s = ff.createSystem(t)
    # get nonbonded force
    for force in s.getForces():
        if isinstance(force, openmm.NonbondedForce):
            nbf = force
            break
    atoms = list(t.atoms())
    atom_elements = []
    atom_charges = []
    for i, atom in enumerate(atoms):
        atom_charges.append(nbf.getParticleParameters(i)[0]._value)
        atom_elements.append(atom.element.symbol)
    types = np.array([mapping[element] for element in atom_elements], dtype=np.int64)
    charges = np.array(atom_charges, dtype=np.float32)
    if save_file_path is not None:
    	np.savez(save_file_path, types=types, charges=charges)
    return types, charges

